import 'package:flextech/flextech.dart';
import 'package:flextech/inputs/date_picker/date_picker.dart';
import 'package:flextech/inputs/date_picker/date_util.dart';
import 'package:flutter/material.dart';

class DateField extends StatefulWidget {
  final String date;
  final ValueChanged<String> selectedDate;
  final double width;
  final ThemeData theme;
  final String label;

  const DateField({
    Key? key,
    required this.date,
    required this.selectedDate,
    this.width = double.infinity,
    required this.theme,
    required this.label,
  }) : super(key: key);

  @override
  _DateFieldState createState() => _DateFieldState();
}

class _DateFieldState extends State<DateField> {
  late String formatted;

  TextEditingController controller = TextEditingController();

  @override
  void initState() {
    formatted = DateUtil.formatDate(widget.date);
    controller.text = formatted;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: 60,
      child: Row(
        children: [
          Expanded(
            child: TextInput(
              theme: widget.theme,
              controller: controller,
              label: widget.label,
              enabled: false,
              text: formatted,
            ),
          ),
          IconButton(
              icon:
                  Icon(Icons.calendar_today, color: widget.theme.primaryColor),
              onPressed: () {
                DatePicker.show(context, widget.theme, DateTime.now(),
                        DateTime(1900, 1, 1), DateTime.now())
                    .then((value) {
                  widget.selectedDate(DateUtil.javaFormat(value));
                  setState(() {
                    formatted = DateUtil.formatDate(value.toString());
                  });
                  controller.text = formatted;
                });
              })
        ],
      ),
    );
  }
}
